/* dump.ino Example sketch for IRLib2
   Illustrates how to receive an IR signal, decode it and print
   information about it to the serial monitor.
*/
//This includes everything. Not generally recommended.
//It's better to include only the parts of library you really need.
//But for this example it's quick and easy. See "comboDump" example
//for a more efficient way.
#include "IRLibAll.h"

IRrecvPCI myReceiver(2); //create receiver and pass pin number
IRdecode myDecoder;   //create decoder

//motor A connected between A01 and A02
//motor B connected between B01 and B02

int STBY = 9; //standby

//Motor A
int PWMA = 6; //Speed control
int AIN1 = 8; //Direction
int AIN2 = 7; //Direction

//Motor B
int PWMB = 10; //Speed control
int BIN1 = 4; //Direction
int BIN2 = 19; //Direction (A5)

int speed = 128;

void move(int motor, int speed, int direction){
//Move specific motor at speed and direction
//motor: 0 for B 1 for A
//speed: 0 is off, and 255 is full speed
//direction: 0 clockwise, 1 counter-clockwise

digitalWrite(STBY, HIGH); //disable standby

boolean inPin1 = LOW;
boolean inPin2 = HIGH;

if(direction == 1){
inPin1 = HIGH;
inPin2 = LOW;
}

if(motor == 1){
  digitalWrite(AIN1, inPin1);
  digitalWrite(AIN2, inPin2);
  analogWrite(PWMA, speed);
}else{
  digitalWrite(BIN1, inPin1);
  digitalWrite(BIN2, inPin2);
  analogWrite(PWMB, speed);
}
}

void stop(){
//enable standby
  digitalWrite(STBY, LOW);
}

void setup() {
  Serial.begin(9600);
  pinMode(15,OUTPUT);
  digitalWrite(15,HIGH);
  myReceiver.enableIRIn(); // Start the receiver
  Serial.println(F("Ready to receive IR signals"));
  pinMode(STBY, OUTPUT);
  pinMode(PWMA, OUTPUT);
  pinMode(AIN1, OUTPUT);
  pinMode(AIN2, OUTPUT);
  pinMode(PWMB, OUTPUT);
  pinMode(BIN1, OUTPUT);
  pinMode(BIN2, OUTPUT);
}

void loop() {
  //Continue looping until you get a complete signal received
  if (myReceiver.getResults()) {
    myDecoder.decode();           //Decode it
//    myDecoder.dumpResults(false);  //Now print results. Use false for less detail
    int value=myDecoder.value&0xff;
    switch(value){
      case 2 :
        move(1, speed, 0);
        move(2, speed, 1);
        break;
      case 4 :
        move(1, speed, 1);
        move(2, speed, 1);
        break;  
      case 6 :
        move(1, speed, 0);
        move(2, speed, 0);
        break;   
      case 8 :
        move(1, speed, 1);
        move(2, speed, 0);
        break; 
    
    }
    Serial.println(value,HEX);
    myReceiver.enableIRIn();      //Restart receiver
  }
}


